translate.convert.po2tmx

Package translate :: Package convert :: Module po2tmx |
[hide private]
[frames] | no frames]

# Module po2tmx

source code

convert Gettext PO localization files to a TMX (Translation Memory eXchange) file

see: http://translate.sourceforge.net/wiki/toolkit/po2tmx for examples and usage instructions

Classes | [hide private]
| po2tmx
| tmxmultifile
| TmxOptionParser

Functions | [hide private]
convertpo(inputfile, outputfile, templatefile, sourcelanguage='en', targetlanguage=None) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: po, tmx, convert, wStringIO, os